import _decorate from "@babel/runtime/helpers/esm/decorate";
import _get from "@babel/runtime/helpers/esm/get";
import _getPrototypeOf from "@babel/runtime/helpers/esm/getPrototypeOf";

let _ = t => t,
    _t;

/**
 * @license
 *
 * Copyright IBM Corp. 2020, 2021
 *
 * This source code is licensed under the Apache-2.0 license found in the
 * LICENSE file in the root directory of this source tree.
 */
import settings from 'carbon-components/es/globals/js/settings';
import { html, property, query, customElement } from 'lit-element';
import Close16 from "../../icons/close/16";
import { filter, forEach } from '../../globals/internal/collection-helpers';
import BXDropdown, { DROPDOWN_KEYBOARD_ACTION } from '../dropdown/dropdown';
import styles from "./multi-select.css.js";
export { DROPDOWN_COLOR_SCHEME, DROPDOWN_SIZE, DROPDOWN_TYPE } from '../dropdown/dropdown';
const {
  prefix
} = settings;
/**
 * Multi select.
 * @element bx-multi-select
 * @fires bx-multi-select-beingselected
 *   The custom event fired before a multi select item is selected upon a user gesture.
 *   Cancellation of this event stops changing the user-initiated selection.
 * @fires bx-multi-select-selected - The custom event fired after a multi select item is selected upon a user gesture.
 * @fires bx-multi-select-beingtoggled
 *   The custom event fired before the open state of this multi select is toggled upon a user gesture.
 *   Cancellation of this event stops the user-initiated toggling.
 * @fires bx-multi-select-toggled
 *   The custom event fired after the open state of this multi select is toggled upon a user gesture.
 */

let BXMultiSelect = _decorate([customElement(`${prefix}-multi-select`)], function (_initialize, _BXDropdown) {
  class BXMultiSelect extends _BXDropdown {
    constructor(...args) {
      super(...args);

      _initialize(this);
    }

  }

  return {
    F: BXMultiSelect,
    d: [{
      kind: "field",
      key: "_selectedItemsCount",

      value() {
        return 0;
      }

    }, {
      kind: "field",
      decorators: [query('#selection-button')],
      key: "_selectionButtonNode",
      value: void 0
    }, {
      kind: "field",
      decorators: [query(`.${prefix}--list-box__field`)],
      key: "_triggerNode",
      value: void 0
    }, {
      kind: "method",
      key: "_selectionShouldChange",
      value:
      /**
       * The count of selected items.
       */

      /**
       * The selection button.
       */

      /**
       * The trigger button.
       */
      function _selectionShouldChange(itemToSelect) {
        // If we are selecting an item, assumes we always toggle
        return Boolean(this.value || itemToSelect);
      }
    }, {
      kind: "method",
      key: "_selectionDidChange",
      value: function _selectionDidChange(itemToSelect) {
        if (itemToSelect) {
          itemToSelect.selected = !itemToSelect.selected;
          this._assistiveStatusText = itemToSelect.selected ? this.selectedItemAssistiveText : this.unselectedItemAssistiveText;
        } else {
          forEach(this.querySelectorAll(this.constructor.selectorItemSelected), item => {
            item.selected = false;
          });

          this._handleUserInitiatedToggle(false);

          this._assistiveStatusText = this.unselectedAllAssistiveText;
        } // Change in `.selected` hasn't been reflected to the corresponding attribute yet


        this.value = filter(this.querySelectorAll(this.constructor.selectorItem), item => item.selected).map(item => item.value).join(',');
      }
    }, {
      kind: "method",
      key: "_handleClickInner",
      value: function _handleClickInner(event) {
        var _this$_selectionButto;

        if ((_this$_selectionButto = this._selectionButtonNode) === null || _this$_selectionButto === void 0 ? void 0 : _this$_selectionButto.contains(event.target)) {
          this._handleUserInitiatedSelectItem();
        } else {
          const shouldIgnoreClickInner = elem => elem.closest && elem.closest(this.constructor.selectorIgnoreClickInner);

          if (!event.composedPath().some(shouldIgnoreClickInner)) {
            _get(_getPrototypeOf(BXMultiSelect.prototype), "_handleClickInner", this).call(this, event);
          }
        }
      }
    }, {
      kind: "method",
      key: "_handleKeydownInner",
      value: function _handleKeydownInner(event) {
        var _this$_selectionButto2;

        const {
          key
        } = event;

        if (((_this$_selectionButto2 = this._selectionButtonNode) === null || _this$_selectionButto2 === void 0 ? void 0 : _this$_selectionButto2.contains(event.target)) && this.constructor.TRIGGER_KEYS.has(key)) {
          this._handleUserInitiatedSelectItem();

          this._triggerNode.focus();
        } else {
          // Ensures up/down keys won't keep focus on "clear selection" button
          if (DROPDOWN_KEYBOARD_ACTION.NAVIGATING === this.constructor.getAction(key)) {
            this._triggerNode.focus();
          }

          _get(_getPrototypeOf(BXMultiSelect.prototype), "_handleKeydownInner", this).call(this, event);
        }
      }
    }, {
      kind: "method",
      key: "_renderPrecedingTriggerContent",
      value: function _renderPrecedingTriggerContent() {
        const {
          clearSelectionLabel,
          _selectedItemsCount: selectedItemsCount
        } = this;
        return selectedItemsCount === 0 ? undefined : html(_t || (_t = _` <div id="selection-button" role="button" class="${0}--list-box__selection ${0}--list-box__selection--multi ${0}--tag--filter" tabindex="0" title="${0}"> ${0} ${0} </div> `), prefix, prefix, prefix, clearSelectionLabel, selectedItemsCount, Close16({
          'aria-label': clearSelectionLabel
        }));
      }
      /**
       * The `aria-label` attribute for the icon to clear selection.
       */

    }, {
      kind: "field",
      decorators: [property({
        attribute: 'clear-selection-label'
      })],
      key: "clearSelectionLabel",

      value() {
        return '';
      }

    }, {
      kind: "field",
      decorators: [property({
        attribute: 'unselected-item-assistive-text'
      })],
      key: "unselectedItemAssistiveText",

      value() {
        return 'Unselected an item.';
      }

    }, {
      kind: "field",
      decorators: [property({
        attribute: 'unselected-all-assistive-text'
      })],
      key: "unselectedAllAssistiveText",

      value() {
        return 'Unselected all items.';
      }

    }, {
      kind: "method",
      key: "shouldUpdate",
      value:
      /**
       * An assistive text for screen reader to announce, telling that an item is unselected.
       */

      /**
       * An assistive text for screen reader to announce, telling that all items are unselected.
       */
      function shouldUpdate(changedProperties) {
        const {
          selectorItem
        } = this.constructor;

        if (changedProperties.has('size')) {
          forEach(this.querySelectorAll(selectorItem), elem => {
            elem.size = this.size;
          });
        }

        if (changedProperties.has('value')) {
          const {
            value
          } = this;
          const values = !value ? [] : value.split(','); // Updates selection beforehand because our rendering logic for `<bx-multi-select>` looks for selected items via `qSA()`

          const items = this.querySelectorAll(selectorItem);
          forEach(items, elem => {
            elem.selected = values.indexOf(elem.value) >= 0;
          });
          this._selectedItemsCount = filter(items, elem => values.indexOf(elem.value) >= 0).length;
        }

        return true;
      }
      /**
       * A selector to ignore the `click` events from.
       * Primary for the checkbox label where the `click` event will happen from the associated check box.
       */

    }, {
      kind: "get",
      static: true,
      key: "selectorIgnoreClickInner",
      value: function selectorIgnoreClickInner() {
        return `.${prefix}--checkbox-label`;
      }
      /**
       * A selector that will return highlighted items.
       */

    }, {
      kind: "get",
      static: true,
      key: "selectorItemHighlighted",
      value: function selectorItemHighlighted() {
        return `${prefix}-multi-select-item[highlighted]`;
      }
      /**
       * A selector that will return multi select items.
       * We use a separate property from `.itemTagName` due to the nature in difference of tag name vs. selector.
       */

    }, {
      kind: "get",
      static: true,
      key: "selectorItem",
      value: function selectorItem() {
        return `${prefix}-multi-select-item`;
      }
      /**
       * A selector that will return selected items.
       */

    }, {
      kind: "get",
      static: true,
      key: "selectorItemSelected",
      value: function selectorItemSelected() {
        return `${prefix}-multi-select-item[selected]`;
      }
      /**
       * The name of the custom event fired before this multi select item is being toggled upon a user gesture.
       * Cancellation of this event stops the user-initiated action of toggling this multi select item.
       */

    }, {
      kind: "get",
      static: true,
      key: "eventBeforeToggle",
      value: function eventBeforeToggle() {
        return `${prefix}-multi-select-beingtoggled`;
      }
      /**
       * The name of the custom event fired after this multi select item is toggled upon a user gesture.
       */

    }, {
      kind: "get",
      static: true,
      key: "eventToggle",
      value: function eventToggle() {
        return `${prefix}-multi-select-toggled`;
      }
      /**
       * The name of the custom event fired before a multi select item is selected upon a user gesture.
       * Cancellation of this event stops changing the user-initiated selection.
       */

    }, {
      kind: "get",
      static: true,
      key: "eventBeforeSelect",
      value: function eventBeforeSelect() {
        return `${prefix}-multi-select-beingselected`;
      }
      /**
       * The name of the custom event fired after a a multi select item is selected upon a user gesture.
       */

    }, {
      kind: "get",
      static: true,
      key: "eventSelect",
      value: function eventSelect() {
        return `${prefix}-multi-select-selected`;
      }
    }, {
      kind: "field",
      static: true,
      key: "styles",

      value() {
        return styles;
      }

    }]
  };
}, BXDropdown);

export default BXMultiSelect;
//# sourceMappingURL=multi-select.js.map
